@@ -17,8 +17,8 @@
 
 """
 Package for parsing ``Authentication-Results`` headers as defined in RFC
-5451/7001.  Optional support for authentication methods defined in RFCs 5617,
-6008, 6212, and 7281.
+5451/7001/7601.  Optional support for authentication methods defined in RFCs
+5617, 6008, 6212, and 7281.
 
 Examples:
 RFC 5451 B.2
@@ -94,7 +94,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.800'
+__version__ = '0.900'
 
 import authres.core
 
