@@ -17,13 +17,13 @@
 
 """
 Package for parsing ``Authentication-Results`` headers as defined in RFC
-5451/7001.  Optional support for authentication methods defined in RFCs 5617,
-6008, 6212, and 7281.
+5451/7001/7601.  Optional support for authentication methods defined in RFCs
+5617, 6008, 6212, and 7281.
 """
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'scott@kitterman.com'
-__version__ = '0.701'
+__version__ = '0.900'
 
 def _test():
     import doctest
